@@ -45,6 +45,7 @@ __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_Display_Shapes.gi
 
 
 class Circle(RoundRect):
+    # pylint: disable=too-few-public-methods, invalid-name
     """A circle.
 
     :param x0: The x-position of the center.
@@ -54,10 +55,18 @@ class Circle(RoundRect):
                  ``None`` for transparent.
     :param outline: The outline of the rounded-corner rectangle. Can be a hex value for a color or
                     ``None`` for no outline.
+    :param stroke: Used for the outline. Will not change the radius.
 
     """
 
-    def __init__(self, x0, y0, r, *, fill=None, outline=None):
+    def __init__(self, x0, y0, r, *, fill=None, outline=None, stroke=1):
         super().__init__(
-            x0 - r, y0 - r, 2 * r + 1, 2 * r + 1, r, fill=fill, outline=outline
+            x0 - r,
+            y0 - r,
+            2 * r + 1,
+            2 * r + 1,
+            r,
+            fill=fill,
+            outline=outline,
+            stroke=stroke,
         )
