@@ -59,6 +59,7 @@ class Rect(displayio.TileGrid):
                    ``height``.
 
     """
+
     def __init__(self, x, y, width, height, *, fill=None, outline=None, stroke=1):
         self._bitmap = displayio.Bitmap(width, height, 2)
         self._palette = displayio.Palette(2)
@@ -68,15 +69,17 @@ class Rect(displayio.TileGrid):
             for w in range(width):
                 for line in range(stroke):
                     self._bitmap[w, line] = 1
-                    self._bitmap[w, height-1-line] = 1
+                    self._bitmap[w, height - 1 - line] = 1
             for _h in range(height):
                 for line in range(stroke):
                     self._bitmap[line, _h] = 1
-                    self._bitmap[width-1-line, _h] = 1
+                    self._bitmap[width - 1 - line, _h] = 1
 
         if fill is not None:
             self._palette[0] = fill
+            self._palette.make_opaque(0)
         else:
+            self._palette[0] = 0
             self._palette.make_transparent(0)
         super().__init__(self._bitmap, pixel_shader=self._palette, x=x, y=y)
 
@@ -89,9 +92,11 @@ class Rect(displayio.TileGrid):
     @fill.setter
     def fill(self, color):
         if color is None:
+            self._palette[0] = 0
             self._palette.make_transparent(0)
         else:
             self._palette[0] = color
+            self._palette.make_opaque(0)
 
     @property
     def outline(self):
@@ -102,6 +107,8 @@ class Rect(displayio.TileGrid):
     @outline.setter
     def outline(self, color):
         if color is None:
+            self._palette[1] = 0
             self._palette.make_transparent(1)
         else:
             self._palette[1] = color
+            self._palette.make_opaque(1)
